/*
 *	Author: Jan Dolezel, http://www.eithel.net
 *	Last version: http://www.eithel.net/download/ui/spiral
 *	Last modified: 2005-11-30
 *
 *	License Information:
 *	-------------------------------------------------------------------------
 *	Copyright (C) 2005 Jan Dolezel, Miroslav Skrbek
 *
 *	This program is free software; you can redistribute it and/or modify it
 *	under the terms of the GNU General Public License as published by the
 *	Free Software Foundation; either version 2 of the License, or (at your
 *	option) any later version.
 *
 *	This program is distributed in the hope that it will be useful, but
 *	WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *	General Public License for more details.
*/

package spirals.data;

import javax.swing.JPanel;
import tablet.*;
import java.awt.*;

/**
 * <p>Class for viewing captured data</p>
 *
 * <p>Copyright: Copyright (c) 2005 Miroslav Skrbek, Jan Dolezel</p>
 * <p>Company: VUT FEL, Prague</p>
 *
 * @author Miroslav Skrbek
 * @author Jan Dolezel
 * @version 1.1.3
 */
public class SkrbekTabletDataViewer extends TabletDataViewer {
  private static final int border_x = 10;
  private static final int border_y = 10;
  private TabletInfo ti;
  private boolean detail = false;
  private boolean showUp = true;

  public SkrbekTabletDataViewer(JPanel screen, TabletData tabletData, boolean showUp) {
    super(screen, tabletData);
    ti = tabletData.getTabletInfo();
    this.showUp = showUp;
  }

  public void paint(Graphics g) {
    int scr_width = screen.getWidth();
    int scr_height = screen.getHeight();
    int scb_width = scr_width - border_x;
    int scb_height = scr_height - border_y;
    int tab_width = ti.getWidth();
    int tab_height = ti.getHeight();

    int nom, denom;
    int offset_x = 0;
    int offset_y = 0;

    float r_w = ( (float) scb_width) / (float) tab_width;
    float r_h = ( (float) scb_height) / (float) tab_height;
    if (r_h > r_w) {
      nom = scb_width;
      denom = tab_width;
    }
    else {
      nom = scb_height;
      denom = tab_height;
    }

    int pic_width = tab_width * nom / denom;
    int pic_height = tab_height * nom / denom;

    int center_x = (scr_width - pic_width) / 2;
    int center_y = (scr_height - pic_height) / 2;

    g.setColor( (detail) ? Color.red : Color.blue);
    g.drawRect(center_x - 1, center_y - 1, pic_width + 1, pic_height + 1);
    g.drawRect(center_x - 2, center_y - 2, pic_width + 3, pic_height + 3);
    g.setColor(Color.white);
    g.fillRect(center_x, center_y, pic_width, pic_height);

    if (detail) {
      int max_x = 0, max_y = 0;
      int min_x = 0, min_y = 0;
      for (int i = 0; i < tabletData.size(); i++) {
        TabletPoint point = tabletData.get(i);
        if (i == 0) {
          min_x = max_x = point.getX();
          min_y = max_y = point.getY();
          continue;
        }
        max_x = Math.max(max_x, point.getX());
        max_y = Math.max(max_y, point.getY());
        min_x = Math.min(min_x, point.getX());
        min_y = Math.min(min_y, point.getY());
      }

      tab_width = max_x - min_x + 1;
      tab_height = max_y - min_y + 1;

      offset_x = -min_x;
      offset_y = -min_y;

      r_w = ( (float) pic_width - 10) / (float) tab_width;
      r_h = ( (float) pic_height - 10) / (float) tab_height;

      if (r_h > r_w) {
        nom = pic_width - border_x;
        denom = tab_width;
      }
      else {
        nom = pic_height - border_y;
        denom = tab_height;
      }

      center_x += (pic_width - tab_width * nom / denom) / 2;
      center_y += (pic_height - tab_height * nom / denom) / 2;

    }

    int x, ox = 0;
    int y, oy = 0;
    boolean pen_down = false;

    g.setColor(Color.black);

    for (int i = 0; i < tabletData.size(); i++) {
      TabletPoint point = tabletData.get(i);
      x = (point.getX() + offset_x) * nom / denom;
      y = (point.getY() + offset_y) * nom / denom;
      x = x + center_x;
      y = scr_height - y - center_y - 2;

      if (!pen_down) {
        if (point.isTouched()) {
          ox = x;
          oy = y;
          pen_down = true;
        }
        continue;
      }

      if (!point.isTouched() && showUp) {
        pen_down = false;
        continue;
      }

      g.drawLine(x, y, ox, oy);
      ox = x;
      oy = y;
    }
  }

  public void setDetail(boolean detail) {
    this.detail = detail;
    screen.repaint();
  }

  public boolean getDetail() {
    return detail;
  }

  public void setShowUp(boolean showUp) {
    this.showUp = showUp;
  }

  public void setTabletInfo(TabletInfo tabletInfo) {
    this.ti = tabletInfo;
  }
}
