/*
 *	Author: Jan Dolezel, http://www.eithel.net
 *	Last version: http://www.eithel.net/download/ui/spiral
 *	Last modified: 2005-09-12
 *
 *	License Information:
 *	-------------------------------------------------------------------------
 *	Copyright (C) 2005 Jan Dolezel
 *
 *	This program is free software; you can redistribute it and/or modify it
 *	under the terms of the GNU General Public License as published by the
 *	Free Software Foundation; either version 2 of the License, or (at your
 *	option) any later version.
 *
 *	This program is distributed in the hope that it will be useful, but
 *	WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *	General Public License for more details.
*/

package spirals.motol.gui;

import spirals.data.*;
import spirals.motol.database.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

/**
 * <p>Frame for viewing captured data from tablet.</p>
 *
 * <p>Copyright: Copyright (c) 2005 Jan Dolezel</p>
 * <p>Company: VUT FEL, Prague</p>
 *
 * @author Jan Dolezel
 * @version 1.1.1
 */
public class DataViewerFrame extends JFrame {
  /**
   * data viewver class
   */
  SimpleTabletDataViewer viewer;
  /**
   * contains content of frame
   */
  JPanel contentPane;

  /**
   * area for view drawing
   */
  JPanel screen = new JPanel() {
    public Dimension getPreferredSize() {
      return new Dimension(600,400);
    }

    public void paintComponent(Graphics g) {
      viewer.paint(g);
    }
  };

  /**
   * create and lay out new viewer frame for Data
   */
  public DataViewerFrame(Visit visit, Data data) {
    super(data.toString());
    Test t = visit.getTestList().get(data.getDescription());
    this.viewer = new SimpleTabletDataViewer(screen, new TabletData(data.getFile(), data.getTabletInfo()), t.showUp());
    this.contentPane = (JPanel) this.getContentPane();
    contentPane.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
    screen.setBorder(BorderFactory.createEtchedBorder());
    JPanel bottom = new JPanel();
    bottom.setBorder(BorderFactory.createEmptyBorder(10,0,0,0));
    bottom.add(new JButton(new AbstractAction("Detail") {
      public void actionPerformed(ActionEvent e) {
        viewer.setDetail(!viewer.getDetail());
        setScreenBorder();
      }
    }));
    bottom.add(Box.createHorizontalStrut(10));
    bottom.add(new JButton(new AbstractAction("Zavi") {
      public void actionPerformed(ActionEvent e) {
        DataViewerFrame.this.dispose();
      }
    }));
    this.add(screen, BorderLayout.CENTER);
    this.add(bottom, BorderLayout.SOUTH);
    this.setScreenBorder();
  }

  /**
   * based on detail, set color of border of viewing area
   */
  private void setScreenBorder() {
    if(viewer.getDetail()) {
      screen.setBorder(BorderFactory.createEtchedBorder(Color.RED, Color.PINK));
    } else {
      screen.setBorder(BorderFactory.createEtchedBorder(Color.BLUE, Color.CYAN));
    }
  }
}
