/*
 *	Author: Jan Dolezel, http://www.eithel.net
 *	Last version: http://www.eithel.net/download/ui/spiral
 *	Last modified: 2005-09-12
 *
 *	License Information:
 *	-------------------------------------------------------------------------
 *	Copyright (C) 2005 Jan Dolezel
 *
 *	This program is free software; you can redistribute it and/or modify it
 *	under the terms of the GNU General Public License as published by the
 *	Free Software Foundation; either version 2 of the License, or (at your
 *	option) any later version.
 *
 *	This program is distributed in the hope that it will be useful, but
 *	WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *	General Public License for more details.
*/

package spirals.motol.gui;

import spirals.motol.database.*;
import javax.swing.*;
import java.awt.*;
import java.text.SimpleDateFormat;

/**
 * <p>Panel showing information about database at startup.</p>
 *
 * <p>Copyright: Copyright (c) 2005 Jan Dolezel</p>
 * <p>Company: VUT FEL, Prague</p>
 *
 * @author Jan Dolezel
 * @version 1.1.1
 */
public class DatabasePanel extends RemovablePanel {
  /**
   * engine
   */
  private Engine engine;
  /**
   * main content of panel
   */
  JPanel main = new JPanel(new GridBagLayout());

  /**
   * create panel and layout
   */
  public DatabasePanel(Engine engine) {
    super(new BorderLayout());
    this.engine = engine;
    this.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));
    this.setFont(engine.getMainFrame().getBigFont());

    JTextField size = new JTextField(String.format("%.2f", (float)engine.getDatabase().getDatabaseSize() / 1024 / 1024) + " MB");
    size.setEditable(false);
    JTextField num = new JTextField(Long.toString(engine.getDatabase().getPacientCount()));
    num.setEditable(false);
    SimpleDateFormat sdf = new SimpleDateFormat("dd. MM. yyyy");
    JTextField last = new JTextField(sdf.format(engine.getDatabase().getLastBackup()));
    last.setEditable(false);
    this.place(0, new JLabel("daje o databzi:"), Box.createHorizontalBox());
    this.place(1, new JLabel(" "), Box.createHorizontalBox());
    this.place(2, new JLabel("Velikost databze:"), size);
    this.place(3, new JLabel("Poet pacient:"), num);
    this.place(4, new JLabel("Datum posledn zlohy:"), last);

    this.add(main, BorderLayout.NORTH);
  }

  /**
   * place two components in gridbag layout on main panel
   * @param row row number in parent component
   * @param c1 first component to place
   * @param c2 second component to place
   */
  private void place(int row, JComponent c1, JComponent c2) {
    main.add(c1, new GridBagConstraints(0, row, 1, 1, 0.0, 1.0, GridBagConstraints.WEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 10), 0, 0));
    main.add(c2, new GridBagConstraints(1, row, 2, 1, 2.0, 1.0, GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    main.add(Box.createHorizontalBox(), new GridBagConstraints(3, row, 2, 1, 2.0, 1.0, GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    c1.setFont(engine.getMainFrame().getDefaultBoldFont());
    c2.setFont(engine.getMainFrame().getDefaultFont());
  }

  /**
   * empty overriden abstract method
   */
  public void remove() {}
}
