/*
 *	Author: Jan Dolezel, http://www.eithel.net
 *	Last version: http://www.eithel.net/download/ui/spiral
 *	Last modified: 2005-09-12
 *
 *	License Information:
 *	-------------------------------------------------------------------------
 *	Copyright (C) 2005 Jan Dolezel
 *
 *	This program is free software; you can redistribute it and/or modify it
 *	under the terms of the GNU General Public License as published by the
 *	Free Software Foundation; either version 2 of the License, or (at your
 *	option) any later version.
 *
 *	This program is distributed in the hope that it will be useful, but
 *	WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *	General Public License for more details.
*/

package spirals.motol.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.tree.*;
import spirals.motol.database.*;

/**
 * <p>Tree with pacients, visits and toolbar</p>
 *
 * <p>Copyright: Copyright (c) 2005 Jan Dolezel</p>
 * <p>Company: VUT FEL, Prague</p>
 *
 * @author Jan Dolezel
 * @version 1.1.1
 */
public class PacientTree extends JPanel {
  /**
   * engine
   */
  private Engine engine;
  /**
   * main frame
   */
  private MainFrame mf;
  /**
   * main tree
   */
  private JTree tree;
  /**
   * image for pacient icon
   */
  private ImageIcon pacIcon = new ImageIcon(PacientTree.class.getResource("/res/user_info.gif"));
  /**
   * image for visit icon
   */
  private ImageIcon timeIcon = new ImageIcon(PacientTree.class.getResource("/res/time.gif"));
  /**
   * search button
   */
  private Tree_Search_Action searchAction = new Tree_Search_Action(this);
  /**
   * button for result of searching
   */
  private Tree_Lock_Action lockAction = new Tree_Lock_Action(this);
  /**
   * sort button
   */
  private Tree_Sort_Action sortAction = new Tree_Sort_Action(this);

  /**
   * create tree in MainFrame
   */
  public PacientTree(MainFrame frame) {
    this.mf = frame;
    this.engine = frame.getEngine();
    this.setLayout(new BorderLayout());

    createToolBar();
    createTree();
  }

  /**
   * lay out top tool bar
   */
  private void createToolBar() {
    JToolBar toolBar = new JToolBar();
    toolBar.setFloatable(false);
    toolBar.add(searchAction);
    toolBar.add(lockAction);
    toolBar.add(sortAction);
    this.add(toolBar, BorderLayout.NORTH);
  }

  /**
   * lay out main tree
   */
  private void createTree() {
    tree = new JTree(new DatabaseModel(engine.getDatabase()));
    tree.setRootVisible(false);
    DefaultTreeCellRenderer renderer = new DefaultTreeCellRenderer();
    renderer.setLeafIcon(timeIcon);
    renderer.setOpenIcon(pacIcon);
    renderer.setClosedIcon(pacIcon);
    tree.setCellRenderer(renderer);
    tree.setFont(mf.getBigFont());
    tree.getSelectionModel().setSelectionMode(TreeSelectionModel.SINGLE_TREE_SELECTION);

    tree.addMouseListener(new MouseAdapter() {
      // performed when pacient/visit is selected in tree
      public void mouseClicked(MouseEvent e) {
        TreePath p = tree.getLeadSelectionPath();
        if (p != null) {
          try {
            Pacient node = (Pacient) p.getLastPathComponent();
            mf.setRightPanel((RemovablePanel) new PacientPanel(mf, node, false));
          } catch(ClassCastException ex1) {
            try {
              Visit node = (Visit) p.getLastPathComponent();
              mf.setRightPanel((RemovablePanel) new VisitPanel(mf, node, false));
            } catch(ClassCastException ex2) {
              System.err.println("Chyba - neplatny objekt ve strome");
            }
          }
        }
      }
    });
    this.add(new JScrollPane(tree), BorderLayout.CENTER);
  }

  /**
   * return main tree
   */
  public JTree getTree() {
    return tree;
  }

  /**
   * return engine
   */
  public Engine getEngine() {
    return engine;
  }

  /**
   * scroll to and select Visit
   */
  public void scrollTreePath(Visit visit) {
    this.scrollTreePath(visit.getPacient());
    TreePath path = tree.getSelectionPath();
    path = path.pathByAddingChild(visit);
    tree.scrollPathToVisible(path);
    tree.setSelectionPath(path);
    tree.updateUI();
  }

  /**
   * scroll to and select Pacient
   */
  public void scrollTreePath(Pacient pac) {
    TreePath path = new TreePath(tree.getModel().getRoot());
    path = path.pathByAddingChild(pac);
    tree.scrollPathToVisible(path);
    tree.setSelectionPath(path);
    tree.updateUI();
  }

  /**
   * clear selection in main tree
   */
  public void clearSelection() {
    tree.clearSelection();
  }

  /**
   * return MainFrame
   */
  public MainFrame getMainFrame() {
    return mf;
  }

  /**
   * perform virtual clicking on button for result searching
   */
  public void lockClick() {
    lockAction.clickOn();
  }
}

/**
 * <p>Action for search button</p>
 *
 * <p>Copyright: Copyright (c) 2005 Jan Dolezel</p>
 *
 * <p>Company: VUT FEL, Prague</p>
 *
 * @author Jan Dolezel
 * @version 1.1.1
 */
class Tree_Search_Action extends AbstractAction {
  /**
   * parent PacientTree
   */
  private PacientTree adaptee;

  /**
   * create action for PacientTree
   */
  Tree_Search_Action(PacientTree adaptee) {
    super("Hledej", new ImageIcon(PacientTree.class.getResource("/res/search.gif")));
    putValue(SHORT_DESCRIPTION, "Hledej pacienty");
//    putValue(MNEMONIC_KEY, KeyEvent.VK_B);
    this.adaptee = adaptee;
  }

  /**
   * method is called when search button is clicked
   */
  public void actionPerformed(ActionEvent actionEvent) {
    SearchFrame sp = new SearchFrame(adaptee, adaptee.getEngine());
    Dimension dlgSize = sp.getPreferredSize();
    Dimension frmSize = adaptee.getMainFrame().getSize();
    Point loc = adaptee.getMainFrame().getLocation();
    sp.setLocation( (frmSize.width - dlgSize.width) / 2 + loc.x,
                     (frmSize.height - dlgSize.height) / 2 + loc.y);
//    sp.pack();
    sp.setVisible(true);
  }
}

/**
 * <p>Action for search results button</p>
 *
 * <p>Copyright: Copyright (c) 2005 Jan Dolezel</p>
 *
 * <p>Company: VUT FEL, Prague</p>
 *
 * @author Jan Dolezel
 * @version 1.1.1
 */
class Tree_Lock_Action extends JButton implements ActionListener {
  /**
   * parent PacientTree
   */
  private PacientTree adaptee;
  static ImageIcon unlock = new ImageIcon(PacientTree.class.getResource("/res/unlocked.gif"));
  static ImageIcon lock = new ImageIcon(PacientTree.class.getResource("/res/locked.gif"));

  /**
   * create action for PacientTree
   */
  Tree_Lock_Action(PacientTree adaptee) {
    super(unlock);
    this.setToolTipText("Cel databze/vsledky hledn");
    this.adaptee = adaptee;
    this.addActionListener(this);
  }

  /**
   * method is called when sort button is clicked
   */
  public void actionPerformed(ActionEvent actionEvent) {
    if(this.getIcon() == unlock) {
      this.setIcon(lock);
      adaptee.getEngine().setRestricted(true);
    } else {
      this.setIcon(unlock);
      adaptee.getEngine().setRestricted(false);
    }
    adaptee.getTree().updateUI();
  }

  /**
   * method is called when sort button is clicked virtualy
   */
  public void clickOn() {
    this.setIcon(lock);
    adaptee.getEngine().setRestricted(true);
    adaptee.getTree().updateUI();
  }
}

/**
 * <p>Action for sort button</p>
 *
 * <p>Copyright: Copyright (c) 2005 Jan Dolezel</p>
 *
 * <p>Company: VUT FEL, Prague</p>
 *
 * @author Jan Dolezel
 * @version 1.1.1
 */
class Tree_Sort_Action extends AbstractAction {
  /**
   * parent PacientTree
   */
  private PacientTree adaptee;

  /**
   * create action for PacientTree
   */
  Tree_Sort_Action(PacientTree adaptee) {
    super("Sead", new ImageIcon(PacientTree.class.getResource("/res/sort.gif")));
    putValue(SHORT_DESCRIPTION, "Sea pacienty");
//    putValue(MNEMONIC_KEY, KeyEvent.VK_B);
    this.adaptee = adaptee;
  }

  /**
   * method is called when sort button is clicked
   */
  public void actionPerformed(ActionEvent actionEvent) {
    String[] options = {"jmna", "posledn nvtevy", "data narozen"};
    String option = (String) JOptionPane.showInputDialog(adaptee.getMainFrame(), "Seadit pacienty dle", "azen", JOptionPane.INFORMATION_MESSAGE, null, options, options[0]);
    if(option != null) {
      if (option.equals(options[0])) {
        adaptee.getEngine().getDatabase().sort(Database.SORT.byName);
      }
      else if (option.equals(options[1])) {
        adaptee.getEngine().getDatabase().sort(Database.SORT.byLastVisit);
      }
      else if (option.equals(options[2])) {
        adaptee.getEngine().getDatabase().sort(Database.SORT.byBornDate);
      }
    }
  }
}
