/*
 *	Author: Jan Dolezel, http://www.eithel.net
 *	Last version: http://www.eithel.net/download/ui/spiral
 *	Last modified: 2005-09-12
 *
 *	License Information:
 *	-------------------------------------------------------------------------
 *	Copyright (C) 2005 Jan Dolezel
 *
 *	This program is free software; you can redistribute it and/or modify it
 *	under the terms of the GNU General Public License as published by the
 *	Free Software Foundation; either version 2 of the License, or (at your
 *	option) any later version.
 *
 *	This program is distributed in the hope that it will be useful, but
 *	WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *	General Public License for more details.
*/

package spirals.motol.gui;

import spirals.motol.database.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.text.*;
import java.util.Date;

/**
 * <p>Panel with choices for sorting</p>
 *
 * <p>Copyright: Copyright (c) 2005 Jan Dolezel</p>
 * <p>Company: VUT FEL, Prague</p>
 *
 * @author Jan Dolezel
 * @version 1.1.1
 */
public class SearchFrame extends JDialog {
  /**
   * engine
   */
  protected Engine engine;
  /**
   * pacient/visit tree with results
   */
  protected PacientTree tree;
  /**
   * main content of frame
   */
  private JPanel main;

  /**
   * image for up icon
   */
  private ImageIcon up = new ImageIcon(SearchFrame.class.getResource("/res/up.gif"));
  /**
   * image for down icon
   */
  private ImageIcon down = new ImageIcon(SearchFrame.class.getResource("/res/down.gif"));
  /**
   * text field for name start
   */
  protected JTextField nameBegin = new JTextField();
  /**
   * text field for name end
   */
  protected JTextField nameEnd = new JTextField();
  /**
   * use name search
   */
  protected JCheckBox name = new JCheckBox();
  /**
   * formatted text field for date start
   */
  protected JFormattedTextField dateBegin = new JFormattedTextField(new DateFormatter());
  /**
   * formatted text field for date end
   */
  protected JFormattedTextField dateEnd = new JFormattedTextField(new DateFormatter());
  /**
   * use date search
   */
  protected JCheckBox date = new JCheckBox();
  /**
   * formatted text field for born date start
   */
  protected JFormattedTextField bornBegin = new JFormattedTextField(new DateFormatter());
  /**
   * formatted text field for born date end
   */
  protected JFormattedTextField bornEnd = new JFormattedTextField(new DateFormatter());
  /**
   * use born date
   */
  protected JCheckBox born = new JCheckBox();

  /**
   * create and lay out SearchFrame for PacientTree
   */
  public SearchFrame(PacientTree tree, Engine engine) {
    super(engine.getMainFrame(), "Vyber pacienty", true);
    this.engine = engine;
    this.tree = tree;
    main = (JPanel) this.getContentPane();
    this.setLayout(new GridBagLayout());
    this.setSize(new Dimension(400, 260));
    this.setResizable(false);
    main.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createEmptyBorder(5,5,5,5), BorderFactory.createCompoundBorder(BorderFactory.createEtchedBorder(), BorderFactory.createEmptyBorder(10,10,10,10))));
    this.setDefaultCloseOperation(DISPOSE_ON_CLOSE);

    this.place(1, new JLabel("Jmno"), nameBegin, nameEnd, name);
    dateBegin.setValue(new Date());
    dateEnd.setValue(new Date());
    this.place(2, new JLabel("<html>Posledn<br>nvtva</html>"), dateBegin, dateEnd, date);
    bornBegin.setValue(new Date());
    bornEnd.setValue(new Date());
    this.place(3, new JLabel("<html>Datum<br>narozen</html>"), bornBegin, bornEnd, born);
    JPanel bottom = new JPanel();
    bottom.setBorder(BorderFactory.createEmptyBorder(10,10,0,10));
    bottom.add(new JButton(new AbstractAction("Zavi") {
      public void actionPerformed(ActionEvent e) {
        SearchFrame.this.dispose();
      }
    }));
    bottom.add(Box.createHorizontalStrut(10));
    bottom.add(new JButton(new SearchAction(this)));
    main.add(bottom, new GridBagConstraints(0, 4, 5, 1, 0.0, 0.0, GridBagConstraints.EAST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
  }

  /**
   * place four components in gridbag layout on main panel
   * @param row row number in parent component
   * @param c1 first component to place
   * @param c2 second component to place
   * @param c3 third component to place
   * @param c4 fourth component to place
   */
  private void place(int row, JComponent c1, JComponent c2, JComponent c3, JComponent c4) {
    main.add(c1, new GridBagConstraints(0, row, 1, 1, 0.0, 1.0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(0, 0, 0, 20), 0, 0));
    main.add(new JLabel(up), new GridBagConstraints(1, row, 1, 1, 0.0, 1.0, GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 5), 0, 0));
    main.add(c2, new GridBagConstraints(2, row, 1, 1, 1.0, 1.0, GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 0), 0, 0));
    main.add(new JLabel(down), new GridBagConstraints(3, row, 1, 1, 0.0, 1.0, GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(0, 10, 0, 5), 0, 0));
    main.add(c3, new GridBagConstraints(4, row, 1, 1, 1.0, 1.0, GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 0), 0, 0));
    main.add(c4, new GridBagConstraints(5, row, 1, 1, 0.0, 1.0, GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 0), 0, 0));
    c1.setFont(engine.getMainFrame().getDefaultBoldFont());
    c2.setFont(engine.getMainFrame().getDefaultFont());
    c3.setFont(engine.getMainFrame().getDefaultFont());
    c4.setFont(engine.getMainFrame().getDefaultFont());
  }
}

/**
 * <p>Action performed when search button is clicked</p>
 *
 * <p>Copyright: Copyright (c) 2005 Jan Dolezel</p>
 *
 * <p>Company: VUT FEL, Prague</p>
 *
 * @author Jan Dolezel
 * @version 1.1.1
 */
class SearchAction extends AbstractAction {
  /**
   * parent SearchFrame
   */
  SearchFrame adaptee;

  /**
   * create action for SearchFrame
   */
  public SearchAction(SearchFrame adaptee) {
    super("Vyber");
    this.adaptee = adaptee;
  }

  /**
   * method is called when search button is clicked
   */
  public void actionPerformed(ActionEvent e) {
    adaptee.engine.getDatabase().clearRestricted();

    if(adaptee.name.isSelected()) {
      String beg = adaptee.nameBegin.getText();
      String end = adaptee.nameEnd.getText();
      if(beg.equals("") || beg == null) beg = "aaaa";
      if(end.equals("") || end == null) end = "";
      adaptee.engine.getDatabase().setRestrictedName(beg, end);
    }
    if(adaptee.date.isSelected()) {
      adaptee.engine.getDatabase().setRestrictedVisit((Date) adaptee.dateBegin.getValue(),(Date)  adaptee.dateEnd.getValue());
    }
    if(adaptee.born.isSelected()) {
      adaptee.engine.getDatabase().setRestrictedBorn((Date) adaptee.bornBegin.getValue(),(Date)  adaptee.bornEnd.getValue());
    }

    if(adaptee.name.isSelected() || adaptee.date.isSelected() || adaptee.born.isSelected()) {
      adaptee.tree.lockClick();
    }
    adaptee.dispose();
  }
}
